"use strict";
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * hornet-js-database - Ensemble des composants de gestion de base hornet-js
 *
 * @author
 * @version v5.5.0
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */
var logger_1 = require("hornet-js-logger/src/logger");
var injector_1 = require("hornet-js-core/src/inject/injector");
var dbconnect_sequelize_1 = require("hornet-js-database/src/sequelize/dbconnect-sequelize");
var logger = logger_1.Logger.getLogger("hornet-js-database.src.sequelize-utils");
var SequelizeUtils;
(function (SequelizeUtils) {
    /**
     * Initialise une relation entre deux entités de la modélisation connectées par une clé étrangère
     * @param {HornetSequelizeAssociationOptions & { targetKey?: string; }} options
     * targetKey cible de clé primaire autre que celle par défaut
     */
    function initRelationBelongsTo(options) {
        if (!options.fromEntity["associations"] || (options.fromEntity["associations"]
            && !options.fromEntity["associations"][options.alias])) {
            options.fromEntity.belongsTo(options.toEntity, {
                as: options.alias,
                foreignKey: options.foreignKey,
                targetKey: options.targetKey
            });
        }
    }
    SequelizeUtils.initRelationBelongsTo = initRelationBelongsTo;
    /**
     * Initialise une relation multiple entre deux entités de la modélisation
     * @param {HornetSequelizeAssociationOptions & { otherKey?: string }} options
     * otherKey - Nom de l'attribut au sein de l'entité cible référence à l'entité courante (optionnel)
     * throughTable - Nom de la table issue de la relation multiple, portant une référence vers fromEntiy et une vers toEntity
     */
    function initRelationBelongsToMany(options) {
        if (!options.fromEntity["associations"]
            || (options.fromEntity["associations"] && !options.fromEntity["associations"][options.alias])) {
            options.fromEntity.belongsToMany(options.toEntity, {
                as: options.alias,
                through: options.throughTable,
                foreignKey: options.foreignKey,
                otherKey: options.otherKey
            });
        }
    }
    SequelizeUtils.initRelationBelongsToMany = initRelationBelongsToMany;
    /**
     * Initialise une relation entre deux entités de la modélisation connectées par une clé étrangère
     * @param {HornetSequelizeAssociationOptions} options
     */
    function initRelationHasOne(options) {
        if (!options.fromEntity["associations"]
            || (options.fromEntity["associations"] && !options.fromEntity["associations"][options.alias])) {
            options.fromEntity.hasOne(options.toEntity, {
                as: options.alias,
                foreignKey: options.foreignKey
            });
        }
    }
    SequelizeUtils.initRelationHasOne = initRelationHasOne;
    /**
     * Initialise une relation entre deux entités de la modélisation connectées par une clé étrangère
     * @param {HornetSequelizeAssociationOptions& { sourceKey?: string; }} options
     * sourceKey Attribut source servant d'agrégat
     */
    function initRelationHasMany(options) {
        if (!options.fromEntity["associations"]
            || (options.fromEntity["associations"] && !options.fromEntity["associations"][options.alias])) {
            options.fromEntity.hasMany(options.toEntity, {
                as: options.alias,
                foreignKey: options.foreignKey,
                sourceKey: options.sourceKey
            });
        }
    }
    SequelizeUtils.initRelationHasMany = initRelationHasMany;
    /**
     * Enregistre l'instance HornetSequelizeModel dans l'Injector
     * clé : HornetSequelizeModels
     * @param modelName Nom de la classe héritant de HornetSequelizeModel
     */
    function registerModel(modelName, instance) {
        var models = injector_1.Injector.getRegistered("HornetSequelizeModels");
        if (!models) {
            models = [];
        }
        else {
            injector_1.Injector.removeRegistered("HornetSequelizeModels");
        }
        models.push({ instance: instance, name: modelName });
        injector_1.Injector.register("HornetSequelizeModels", models);
    }
    SequelizeUtils.registerModel = registerModel;
    /**
     * Enregistre l'entity dans l'Injector dans un tableau
     * clé : HornetSequelizeEntities
     * @param entity Instance de l'entity
     */
    function registerEntity(entity) {
        var entities = injector_1.Injector.getRegistered("HornetSequelizeEntities");
        if (!entities) {
            entities = [];
        }
        else {
            injector_1.Injector.removeRegistered("HornetSequelizeEntities");
        }
        entities.push(entity);
        injector_1.Injector.register("HornetSequelizeEntities", entities);
    }
    SequelizeUtils.registerEntity = registerEntity;
    /**
     * @param configName
     */
    function getQuery(configName) {
        return dbconnect_sequelize_1.DbConnect.global[configName || dbconnect_sequelize_1.DbConnect.defaultConfigName].sequelize;
    }
    SequelizeUtils.getQuery = getQuery;
})(SequelizeUtils = exports.SequelizeUtils || (exports.SequelizeUtils = {}));

//# sourceMappingURL=sequelize-utils.js.map
